AppRequest

Enum AppRequest 

pub enum AppRequest {
    AppInfo,
    AgentInfo {
        dna_hashes: Option<Vec<DnaHash>>,
    },
    PeerMetaInfo {
        url: Url,
        dna_hashes: Option<Vec<DnaHash>>,
    },
    CallZome(Box<ZomeCallParamsSigned>),
    CreateCloneCell(Box<CreateCloneCellPayload>),
    DisableCloneCell(Box<DisableCloneCellPayload>),
    EnableCloneCell(Box<EnableCloneCellPayload>),
    DumpNetworkMetrics {
        dna_hash: Option<DnaHash>,
        include_dht_summary: bool,
    },
    DumpNetworkStats,
    ListWasmHostFunctions,
    ProvideMemproofs(MemproofMap),
    EnableApp,
}
Represents the available conductor functions to call over an app interface and will result in a corresponding AppResponse message being sent back over the interface connection.

Errors

Returns an AppResponse::Error with a reason why the request failed.

Variants



AppInfo

Get info about the app that you are connected to, including info about each cell installed by this app.

Returns

AppResponse::AppInfo



AgentInfo

Request information about the agents in this Conductor’s peer store.

This is limited to cells of the app you are connected to.

Returns

AppResponse::AgentInfo

Fields

dna_hashes: Option<Vec<DnaHash>>

Optionally limit the results to specific DNA hashes



PeerMetaInfo

Request the contents of the peer meta store(s) related to the given dna hashes for the agent at the given Url.

If dna_hashes is set to None it returns the contents for all dnas of the app.

Returns

AppResponse::PeerMetaInfo

Fields

url: Url
dna_hashes: Option<Vec<DnaHash>>


CallZome(Box<ZomeCallParamsSigned>)

Call a zome function.

The payload to this call is composed of the serialized ZomeCallParams as bytes and the provenance’s signature.

Serialization must be performed with MessagePack. The resulting bytes are hashed using the SHA2 512-bit algorithm, and the hash is signed with the provenance’s private ed25519 key. The hash is not included in the call’s payload.

Returns

AppResponse::ZomeCalled Indicates the zome call was deserialized successfully. If the call was authorized, the response yields the return value of the zome function as MessagePack encoded bytes. The bytes can be deserialized to the expected return type.

This response is also returned when authorization of the zome call failed because of an invalid signature, capability grant or nonce.

Errors

SerializedBytesError is returned when the serialized bytes could not be deserialized to the expected ZomeCallParams.



CreateCloneCell(Box<CreateCloneCellPayload>)

Clone a DNA (in the biological sense), thus creating a new Cell.

Using the provided, already-registered DNA, create a new DNA with a unique ID and the specified properties, create a new cell from this cloned DNA, and add the cell to the specified app.

Returns

AppResponse::CloneCellCreated



DisableCloneCell(Box<DisableCloneCellPayload>)

Disable a clone cell.

Providing a CloneId or CellId, disable an existing clone cell. When the clone cell exists, it is disabled and can not be called any longer. If it doesn’t exist, the call is a no-op.

Returns

AppResponse::CloneCellDisabled if the clone cell existed and has been disabled.



EnableCloneCell(Box<EnableCloneCellPayload>)

Enable a clone cell that was previously disabled.

Returns

AppResponse::CloneCellEnabled



DumpNetworkMetrics

Retrieve network metrics for the current app.

Identical to what AdminRequest::DumpNetworkMetrics does, but scoped to the current app.

If dna_hash is not set, metrics for all DNAs in the current app are returned.

Returns

AppResponse::NetworkMetricsDumped

Fields

dna_hash: Option<DnaHash>

If set, limits the metrics dumped to a single DNA hash space.

include_dht_summary: bool

Whether to include a DHT summary.

You need a dump from multiple nodes in order to make a comparison, so this is not requested by default.



DumpNetworkStats

Dump network statistics from the Kitsune2 networking transport module.

Identical to what AdminRequest::DumpNetworkStats does, but scoped to the current app. Connections that are not relevant to a DNA in the current app are filtered out.

Returns

AppResponse::NetworkStatsDumped



ListWasmHostFunctions

List all host functions available to wasm on this conductor.

Returns

AppResponse::ListWasmHostFunctions



ProvideMemproofs(MemproofMap)

Provide the membrane proofs for this app, if this app was installed using allow_deferred_memproofs and memproofs were not provided at installation time.

Returns

AppResponse::Ok



EnableApp

Enable the app, only in special circumstances. Can only be called while the app is in the Disabled(NotStartedAfterProvidingMemproofs) state. Cannot be used to enable the app if it’s in any other state, or Disabled for any other reason.

Returns

AppResponse::Ok