pub enum AppResponse {
Error(ExternalApiWireError),
AppInfo(Option<AppInfo>),
AgentInfo(Vec<String>),
ZomeCalled(Box<ExternIO>),
CloneCellCreated(ClonedCell),
CloneCellDisabled,
CloneCellEnabled(ClonedCell),
NetworkMetricsDumped(HashMap<DnaHash, Kitsune2NetworkMetrics>),
NetworkStatsDumped(TransportStats),
ListWasmHostFunctions(Vec<String>),
Ok,
}Expand description
Represents the possible responses to an AppRequest.
Variants
Error(ExternalApiWireError)
Can occur in response to any AppRequest.
There has been an error during the handling of the request.
AppInfo(Option<AppInfo>)
The successful response to an AppRequest::AppInfo.
Option will be None if there is no installed app with the given installed_app_id.
AgentInfo(Vec<String>)
The successful response to an AppRequest::AgentInfo.
ZomeCalled(Box<ExternIO>)
The successful response to an AppRequest::CallZome.
Note that ExternIO is simply a structure of SerializedBytes, so the client will have
to decode this response back into the data provided by the zome using a msgpack library to utilize it.
CloneCellCreated(ClonedCell)
The successful response to an AppRequest::CreateCloneCell.
The response contains the created clone ClonedCell.
CloneCellDisabled
The successful response to an AppRequest::DisableCloneCell.
An existing clone cell has been disabled.
CloneCellEnabled(ClonedCell)
The successful response to an AppRequest::EnableCloneCell.
A previously disabled clone cell has been enabled. The ClonedCell
is returned.
NetworkMetricsDumped(HashMap<DnaHash, Kitsune2NetworkMetrics>)
The successful result of a call to AppRequest::DumpNetworkMetrics.
NetworkStatsDumped(TransportStats)
The successful result of a call to AppRequest::DumpNetworkStats.
ListWasmHostFunctions(Vec<String>)
All the wasm host functions supported by this conductor.
Ok
Operation successful, no payload.