pub struct AppAuthenticationRequest {
pub token: AppAuthenticationToken,
}Expand description
The request payload sent on a Holochain app websocket to authenticate the connection.
Fields
token: AppAuthenticationTokenThe authentication token that was provided by the conductor when crate::admin_interface::AdminRequest::IssueAppAuthenticationToken was called.