pub struct AppInfo {
pub installed_app_id: InstalledAppId,
pub cell_info: IndexMap<RoleName, Vec<CellInfo>>,
pub status: AppStatus,
pub agent_pub_key: AgentPubKey,
pub manifest: AppManifest,
pub installed_at: Timestamp,
}Expand description
Info about an installed app, returned as part of AppResponse::AppInfo
Fields
installed_app_id: InstalledAppIdThe unique identifier for an installed app in this conductor
cell_info: IndexMap<RoleName, Vec<CellInfo>>Info about the cells installed in this app. Lists of cells are ordered and contain first the provisioned cell, then enabled clone cells and finally disabled clone cells.
status: AppStatusThe app’s current status, in an API-friendly format
agent_pub_key: AgentPubKeyThe app’s agent pub key.
manifest: AppManifestThe original AppManifest used to install the app, which can also be used to install the app again under a new agent.
installed_at: TimestampThe timestamp when this app was installed.
Implementations
Sourceimpl AppInfo
impl AppInfo
pub fn from_installed_app( app: &InstalledApp, dna_definitions: &IndexMap<CellId, DnaDefHashed>, ) -> Self