IssueAppAuthenticationTokenPayload

Struct IssueAppAuthenticationTokenPayload 

pub struct IssueAppAuthenticationTokenPayload {
    pub installed_app_id: InstalledAppId,
    pub expiry_seconds: u64,
    pub single_use: bool,
}
Fields

installed_app_id: InstalledAppId

The app ID to issue a connection token for.

expiry_seconds: u64

The number of seconds that the token should be valid for. After this number of seconds, the token will no longer be accepted by the conductor.

This is 30s by default which is reasonably high but with IssueAppAuthenticationTokenPayload::single_use set to true, the token will be invalidated after the first use anyway.

Set this to 0 to create a token that does not expire.

single_use: bool

Whether the token should be single-use. This is true by default and will cause the token to be invalidated after the first use, irrespective of connection success.

Set this to false to allow the token to be used multiple times.

Implementations

Source

impl IssueAppAuthenticationTokenPayload

pub fn for_installed_app_id(installed_app_id: InstalledAppId) -> Self

Create a new payload for issuing a connection token for the specified app.

The token will be valid for 30 seconds and for a single use.

pub fn expiry_seconds(self, expiry_seconds: u64) -> Self

Set the expiry time for the token.

pub fn single_use(self, single_use: bool) -> Self

Set whether the token should be single-use.