pub struct NetworkInfo {
pub fetch_pool_info: FetchPoolInfo,
pub current_number_of_peers: u32,
pub arc_size: f64,
pub total_network_peers: u32,
pub bytes_since_last_time_queried: u64,
pub completed_rounds_since_last_time_queried: u32,
}Fields
fetch_pool_info: FetchPoolInfocurrent_number_of_peers: u32arc_size: f64total_network_peers: u32bytes_since_last_time_queried: u64completed_rounds_since_last_time_queried: u32Trait Implementations
sourceimpl Clone for NetworkInfo
impl Clone for NetworkInfo
sourcefn clone(&self) -> NetworkInfo
fn clone(&self) -> NetworkInfo
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NetworkInfo
impl Debug for NetworkInfo
sourceimpl<'de> Deserialize<'de> for NetworkInfo
impl<'de> Deserialize<'de> for NetworkInfo
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for NetworkInfo
impl PartialEq for NetworkInfo
sourceimpl Serialize for NetworkInfo
impl Serialize for NetworkInfo
sourceimpl TryFrom<&NetworkInfo> for SerializedBytes
impl TryFrom<&NetworkInfo> for SerializedBytes
sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
sourcefn try_from(t: &NetworkInfo) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: &NetworkInfo) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
sourceimpl TryFrom<NetworkInfo> for SerializedBytes
impl TryFrom<NetworkInfo> for SerializedBytes
sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
sourcefn try_from(t: NetworkInfo) -> Result<SerializedBytes, SerializedBytesError>
fn try_from(t: NetworkInfo) -> Result<SerializedBytes, SerializedBytesError>
Performs the conversion.
sourceimpl TryFrom<SerializedBytes> for NetworkInfo
impl TryFrom<SerializedBytes> for NetworkInfo
sourcetype Error = SerializedBytesError
type Error = SerializedBytesError
The type returned in the event of a conversion error.
sourcefn try_from(sb: SerializedBytes) -> Result<NetworkInfo, SerializedBytesError>
fn try_from(sb: SerializedBytes) -> Result<NetworkInfo, SerializedBytesError>
Performs the conversion.
impl StructuralPartialEq for NetworkInfo